@@ -7,6 +7,8 @@ from astropy.coordinates import Angle, Longitude, Latitude, SkyCoord
 from ...utils.fitting import Parameter, Model
 from ...maps import Map
 from scipy.integrate import quad
+from scipy.special import erf
+
 
 __all__ = [
     "SkySpatialModel",
@@ -22,6 +24,13 @@ __all__ = [
 
 log = logging.getLogger(__name__)
 
+EDGE_WIDTH_95 = 2.326174307353347
+
+
+def smooth_edge(x, width):
+    value = (x / width).to_value("")
+    return 0.5 * (1 - erf(value * EDGE_WIDTH_95))
+
 
 class SkySpatialModel(Model):
     """Sky spatial model base class."""
@@ -48,10 +57,7 @@ class SkySpatialModel(Model):
 class SkyPointSource(SkySpatialModel):
     r"""Point Source.
 
-    .. math::
-
-        \phi(lon, lat) = \delta{(lon - lon_0, lat - lat_0)}
-
+    .. math:: \phi(lon, lat) = \delta{(lon - lon_0, lat - lat_0)}
 
     Parameters
     ----------
@@ -108,7 +114,6 @@ class SkyGaussian(SkySpatialModel):
     r"""Two-dimensional symmetric Gaussian model
 
     .. math::
-
         \phi(\text{lon}, \text{lat}) = N \times \text{exp}\left\{-\frac{1}{2}
             \frac{1-\text{cos}\theta}{1-\text{cos}\sigma}\right\}\,,
 
@@ -118,7 +123,6 @@ class SkyGaussian(SkySpatialModel):
     the sphere:
 
     .. math::
-
         N = \frac{1}{4\pi a\left[1-\text{exp}(-1/a)\right]}\,,\,\,\,\,
         a = 1-\text{cos}\sigma\,.
 
@@ -126,7 +130,6 @@ class SkyGaussian(SkySpatialModel):
     In the limit of small :math:`\theta` and :math:`\sigma`, this definition reduces to the usual form:
 
     .. math::
-
         \phi(\text{lon}, \text{lat}) = \frac{1}{2\pi\sigma^2} \exp{\left(-\frac{1}{2}
             \frac{\theta^2}{\sigma^2}\right)}
 
@@ -180,14 +183,15 @@ class SkyDisk(SkySpatialModel):
     r"""Constant radial disk model.
 
     .. math::
-
         \phi(lon, lat) = \frac{1}{2 \pi (1 - \cos{r_0}) } \cdot
                 \begin{cases}
                     1 & \text{for } \theta \leq r_0 \\
                     0 & \text{for } \theta > r_0
                 \end{cases}
 
-    where :math:`\theta` is the sky separation
+    where :math:`\theta` is the sky separation. To improve fit convergence of the
+    model, the sharp edges is smoothed using `~scipy.special.erf`.
+
 
     Parameters
     ----------
@@ -197,21 +201,61 @@ class SkyDisk(SkySpatialModel):
         :math:`lat_0`
     r_0 : `~astropy.coordinates.Angle`
         :math:`r_0`
+    edge : `~astropy.coordinates.Angle`
+        Width of the edge. The width is defined as the range within the
+        smooth edges of the model drops from 95% to 5% of its amplitude
+        (see illustration below).
     frame : {"galactic", "icrs"}
         Coordinate frame of `lon_0` and `lat_0`.
+
+
+    Examples
+    --------
+    Here is an illustration of the definition of the edge parameter:
+
+    .. plot::
+        :include-source:
+
+        import matplotlib.pyplot as plt
+        from astropy import units as u
+        from gammapy.image.models import SkyDisk
+
+        lons = np.linspace(0, 0.3, 500) * u.deg
+
+        r_0 = 0.2 * u.deg
+        edge = 0.1 * u.deg
+
+        disk = SkyDisk(lon_0="0 deg", lat_0="0 deg", r_0=r_0, edge=edge)
+        profile = disk(lons, 0 * u.deg)
+        plt.plot(lons, profile / profile.max(), alpha=0.5)
+        plt.xlabel("Radius (deg)")
+        plt.ylabel("Profile (A.U.)")
+
+        edge_min, edge_max = (r_0 - edge / 2.).value, (r_0 + edge / 2.).value
+        plt.vlines([edge_min, edge_max], 0, 1, linestyles=["--"])
+        plt.annotate("", xy=(edge_min, 0.5), xytext=(edge_min + edge.value, 0.5),
+                     arrowprops=dict(arrowstyle="<->", lw=2))
+        plt.text(0.2, 0.52, "Edge width", ha="center", size=12)
+        plt.hlines([0.95], edge_min - 0.02, edge_min + 0.02, linestyles=["-"])
+        plt.text(edge_min + 0.02, 0.95, "95%", size=12, va="center")
+        plt.hlines([0.05], edge_max - 0.02, edge_max + 0.02, linestyles=["-"])
+        plt.text(edge_max - 0.02, 0.05, "5%", size=12, va="center", ha="right")
+        plt.show()
+
     """
 
     __slots__ = ["frame", "lon_0", "lat_0", "r_0"]
 
-    def __init__(self, lon_0, lat_0, r_0, frame="galactic"):
+    def __init__(self, lon_0, lat_0, r_0, edge="0.01 deg", frame="galactic"):
         self.frame = frame
         self.lon_0 = Parameter(
             "lon_0", Longitude(lon_0).wrap_at("180d"), min=-180, max=180
         )
         self.lat_0 = Parameter("lat_0", Latitude(lat_0), min=-90, max=90)
         self.r_0 = Parameter("r_0", Angle(r_0))
+        self.edge = Parameter("edge", Angle(edge), min=0.01, frozen=True)
 
-        super().__init__([self.lon_0, self.lat_0, self.r_0])
+        super().__init__([self.lon_0, self.lat_0, self.r_0, self.edge])
 
     @property
     def evaluation_radius(self):
@@ -226,13 +270,15 @@ class SkyDisk(SkySpatialModel):
         return self.parameters["r_0"].quantity
 
     @staticmethod
-    def evaluate(lon, lat, lon_0, lat_0, r_0):
+    def evaluate(lon, lat, lon_0, lat_0, r_0, edge):
         """Evaluate the model (static function)."""
         sep = angular_separation(lon, lat, lon_0, lat_0)
 
         # Surface area of a spherical cap, see https://en.wikipedia.org/wiki/Spherical_cap
         norm = 1.0 / (2 * np.pi * (1 - np.cos(r_0)))
-        return u.Quantity(norm.value * (sep <= r_0), "sr-1", copy=False)
+
+        in_disk = smooth_edge(sep - r_0, edge)
+        return u.Quantity(norm.value * in_disk, "sr-1", copy=False)
 
 
 class SkyEllipse(SkySpatialModel):
@@ -270,6 +316,10 @@ class SkyEllipse(SkySpatialModel):
         :math:`\theta`:
         Rotation angle of the major semiaxis.  The rotation angle increases clockwise
         (i.e., East of North) from the positive `lon` axis.
+    edge : `~astropy.coordinates.Angle`
+        Width of the edge. The width is defined as the range within the
+        smooth edges of the model drops from 95% to 5% of its amplitude
+        (see illustration for `SkyDisk`).
     frame : {"galactic", "icrs"}
         Coordinate frame of `lon_0` and `lat_0`.
 
@@ -306,7 +356,9 @@ class SkyEllipse(SkySpatialModel):
 
     __slots__ = ["frame", "lon_0", "lat_0", "semi_major", "e", "theta", "_offset_by"]
 
-    def __init__(self, lon_0, lat_0, semi_major, e, theta, frame="galactic"):
+    def __init__(
+        self, lon_0, lat_0, semi_major, e, theta, edge="0.01 deg", frame="galactic"
+    ):
         try:
             from astropy.coordinates.angle_utilities import offset_by
 
@@ -322,8 +374,11 @@ class SkyEllipse(SkySpatialModel):
         self.semi_major = Parameter("semi_major", Angle(semi_major))
         self.e = Parameter("e", e, min=0, max=1)
         self.theta = Parameter("theta", Angle(theta))
+        self.edge = Parameter("edge", Angle(edge), frozen=True, min=0.01)
 
-        super().__init__([self.lon_0, self.lat_0, self.semi_major, self.e, self.theta])
+        super().__init__(
+            [self.lon_0, self.lat_0, self.semi_major, self.e, self.theta, self.edge]
+        )
 
     @property
     def evaluation_radius(self):
@@ -356,7 +411,7 @@ class SkyEllipse(SkySpatialModel):
             2 * quad(lambda x: integral_fcn(x, semi_major, semi_minor), 0, np.pi)[0]
         ) ** -1
 
-    def evaluate(self, lon, lat, lon_0, lat_0, semi_major, e, theta):
+    def evaluate(self, lon, lat, lon_0, lat_0, semi_major, e, theta, edge):
         """Evaluate the model (static function)."""
         # find the foci of the ellipse
         c = semi_major * e
@@ -365,7 +420,8 @@ class SkyEllipse(SkySpatialModel):
 
         sep_1 = angular_separation(lon, lat, lon_1, lat_1)
         sep_2 = angular_separation(lon, lat, lon_2, lat_2)
-        in_ellipse = sep_1 + sep_2 <= 2 * semi_major
+
+        in_ellipse = smooth_edge(sep_1 + sep_2 - 2 * semi_major, 2 * edge)
 
         norm = SkyEllipse.compute_norm(semi_major, e)
         return u.Quantity(norm * in_ellipse, "sr-1", copy=False)
@@ -375,7 +431,6 @@ class SkyShell(SkySpatialModel):
     r"""Shell model.
 
     .. math::
-
         \phi(lon, lat) = \frac{3}{2 \pi (r_{out}^3 - r_{in}^3)} \cdot
                 \begin{cases}
                     \sqrt{r_{out}^2 - \theta^2} - \sqrt{r_{in}^2 - \theta^2} &
@@ -574,3 +629,7 @@ class SkyDiffuseMap(SkySpatialModel):
     def position(self):
         """`~astropy.coordinates.SkyCoord`"""
         return self.map.geom.center_skydir
+
+    @property
+    def frame(self):
+        return self.position.frame.name
